@@ -15,25 +15,6 @@ using TreeTools::ClusterTable;
 #include <cmath> /* for log2(), ceil() */
 #include <memory> /* for unique_ptr, make_unique */
 
-// Modelled on https://CRAN.R-project.org/package=Rcpp/vignettes/Rcpp-modules.pdf
-// [[Rcpp::export]]
-SEXP ClusterTable_new(List phylo) {
-  XPtr<ClusterTable> ptr(new ClusterTable (phylo), true);
-  return ptr;
-}
-
-// [[Rcpp::export]]
-IntegerMatrix ClusterTable_matrix(SEXP xp) {
-  XPtr<ClusterTable> ptr(xp);
-  return ptr->X_contents();
-}
-
-// [[Rcpp::export]]
-IntegerVector ClusterTable_decode(SEXP xp) {
-  XPtr<ClusterTable> ptr(xp);
-  return ptr->X_decode();
-}
-
 // COMCLUSTER computes a strict consensus tree in O(knn).
 // COMCLUST requires O(kn).
 // trees is a list of objects of class phylo.
@@ -101,15 +82,18 @@ double consensus_info (const List trees, const LogicalVector phylo,
   const int16 n_trees = trees.length();
   
   std::vector<ClusterTable> tables;
+  if (std::size_t(n_trees) > tables.max_size()) {
+    Rcpp::stop("Not enough memory available to compute consensus of so many trees");
+  }
   tables.reserve(n_trees);
   for (int16 i = n_trees; i--; ) {
     tables.emplace_back(ClusterTable(List(trees(i))));
   }
   
   if (p[0] > 1) {
-    throw std::range_error("p must be <= 1.0 in consensus_info()");
+    Rcpp::stop("p must be <= 1.0 in consensus_info()");
   } else if (p[0] < 0.5) {
-    throw std::range_error("p must be >= 0.5 in consensus_info()");
+    Rcpp::stop("p must be >= 0.5 in consensus_info()");
   }
   const int16
     n_tip = tables[0].N(),
